@@ -12,13 +12,13 @@ use Test::More;
 use T::To;
 use base 'T::To';
 use Data::Dumper;
-use XML::SAX::Writer;
+use XML::ExtOn::Writer;
 use XML::ExtOn('create_pipe');
 
 sub make_doc_parser {
     my $t          = shift;
     my $out        = shift;
-    my $xml_writer = new XML::SAX::Writer:: Output => $out;
+    my $xml_writer = new XML::ExtOn::Writer:: Output => $out;
     my $out_filters =
       create_pipe( create_pipe( @_ ? @_ : 'XML::ExtOn', $xml_writer ) );
     my ( $p, $f ) = Perl6::Pod::To::to_abstract(
